@@ -111,7 +111,7 @@ def _scan_dir(start_path: str, extension: str = None) -> Iterator[str]:
     for root, dirs, files in os.walk(start_path):
         for file in files:
             if extension:
-                if file[len(extension) * -1:].lower() == extension.lower():
+                if file[len(extension) * -1 :].lower() == extension.lower():
                     yield os.path.join(root, file)
             else:
                 yield os.path.join(root, file)
@@ -132,8 +132,8 @@ def _find_sitemaps(base_url: str) -> List[str]:
     response = requests.get(base_url + "robots.txt")
     if response.status_code == 200:
         for line in response.text.split("\n"):
-            if line[0:len("Sitemap:")].lower() == "sitemap:":
-                sitemaps_found.append(line[len("Sitemap:"):].strip())
+            if line[0 : len("Sitemap:")].lower() == "sitemap:":
+                sitemaps_found.append(line[len("Sitemap:") :].strip())
     # usual suspects
     response = requests.get(base_url + "sitemap.txt")
     if response.status_code == 200:
@@ -191,9 +191,9 @@ def index(
     (re)Index documents
     """
 
+    es = _es_handle(elasticsearch_host, elasticsearch_port)
     use_es = True
     try:
-        es = _es_handle(elasticsearch_host, elasticsearch_port)
         # with warnings.catch_warnings():
         #    warnings.simplefilter("never")
         es.indices.delete(index=elasticsearch_index_name, ignore=[400, 404])
@@ -218,7 +218,7 @@ def index(
             doc = {
                 "title": title,
                 "text": text,
-                "path": file_path[len(documents_folder):],
+                "path": file_path[len(documents_folder) :],
             }
             index_file.write("{}\n".format(json.dumps(doc)))
             if use_es:
@@ -231,6 +231,7 @@ def _wget(
     destination_folder: str = ".",
     auth_user: str = None,
     auth_password: str = None,
+    ignore_robots_txt: bool = False,
 ):
     global MEDUSE_VERBOSE_MODE
     sh_command = [
@@ -246,6 +247,9 @@ def _wget(
         else "--append-output={}/{}".format(destination_folder, "wget.log"),
     ]
 
+    if ignore_robots_txt:
+        sh_command.append("-erobots=off")
+
     if auth_user and auth_password:
         sh_command.append("--http-user={}".format(auth_user))
         sh_command.append("--http-password={}".format(auth_password))
@@ -275,6 +279,7 @@ def mirror(
     pre_indexing_hook: pre_index_hook_help = "",
     auth_user: "HTTP Basic Auth user" = None,
     auth_password: "HTTP Basic Auth password" = None,
+    ignore_robots_txt: bool = False,
 ):
     """
     Mirror website and index documents.
@@ -300,7 +305,11 @@ def mirror(
         )
     )
     _wget(
-        source_url, destination_folder, auth_user=auth_user, auth_password=auth_password
+        source_url,
+        destination_folder,
+        auth_user=auth_user,
+        auth_password=auth_password,
+        ignore_robots_txt=ignore_robots_txt,
     )
     _verbose_print("wget mirror done.")
 
@@ -316,6 +325,7 @@ def mirror(
                     destination_folder,
                     auth_user=auth_user,
                     auth_password=auth_password,
+                    ignore_robots_txt=ignore_robots_txt,
                 )
 
     _verbose_print("Patching HTML documents...")
@@ -384,6 +394,7 @@ def serve(
 
         else:
             raise InvalidUsage
+
     app.static("/", root_directory)
     app.run(host=host, port=port)
 
